@@ -3,7 +3,7 @@
 import networkx
 from networkx.exception import NetworkXError
 from collections import MutableMapping
-from gorm.json import ismutable, JSONWrapper
+from gorm.xjson import ismutable, JSONWrapper, JSONListWrapper
 
 
 class GraphMapping(MutableMapping):
@@ -70,13 +70,15 @@ class GraphMapping(MutableMapping):
                     branch,
                     rev
                 )
-                if ismutable(r):
+                if isinstance(r, list):
+                    return JSONListWrapper(self, key)
+                elif ismutable(r):
                     return JSONWrapper(self, key)
                 else:
                     return r
             except KeyError:
                 continue
-        raise KeyError("key is not set, ever")
+        raise KeyError("key {} is not set, ever".format(key))
 
     def __setitem__(self, key, value):
         """Set key=value at the present branch and revision"""
@@ -157,7 +159,9 @@ class Node(GraphMapping):
     def __getitem__(self, key):
         """Get the value of the key at the present branch and rev"""
         r = self._get(key)
-        if ismutable(r):
+        if isinstance(r, list):
+            return JSONListWrapper(self, key)
+        elif ismutable(r):
             return JSONWrapper(self, key)
         else:
             return r
@@ -237,7 +241,9 @@ class Edge(GraphMapping):
 
         """
         r = self._get(key)
-        if ismutable(r):
+        if isinstance(r, list):
+            return JSONListWrapper(self, key)
+        elif ismutable(r):
             return JSONWrapper(self, key)
         else:
             return r
@@ -316,7 +322,7 @@ class GraphNodeMapping(GraphMapping):
         """If the node exists at present, return it, else throw KeyError"""
         if node not in self:
             raise KeyError("Node doesn't exist")
-        return Node(self.graph.node)
+        return Node(self.graph, node)
 
     def __setitem__(self, node, dikt):
         """Only accept dict-like values for assignment. These are taken to be
@@ -444,17 +450,16 @@ class AbstractSuccessors(GraphEdgeMapping):
 
     def __getitem__(self, nodeB):
         """Get the edge between my nodeA and the given node"""
-        return Edge(self.graph, *self._order_nodes(nodeB))
+        return Edge(self.graph, self.nodeA, nodeB)
 
     def __setitem__(self, nodeB, value):
         """Set the edge between my nodeA and the given nodeB to the given
         value, a mapping.
 
         """
-        (nodeA, nodeB) = self._order_nodes(nodeB)
         self.gorm.db.exist_edge(
             self.graph.name,
-            nodeA,
+            self.nodeA,
             nodeB,
             0,
             self.gorm.branch,
